VekterDB
========

VekterDB turns any SQLAlchemy compliant database into a vector database by utilizing
FAISS to index the vectors.


Installation
============
VekterDB may be install using pip

    pip install vekterdb


Documentation
=============
Documentation can be found at https://mhendrey.github.io/vekterdb

